==> vcloud-1.0.0-sources.jar: org/jclouds/vcloud/options/CaptureVAppOptions.java <==
/**
 *
 * Copyright (C) 2011 Cloud Conscious, LLC. <info@cloudconscious.com>
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */
package org.jclouds.vcloud.options;

import static com.google.common.base.Preconditions.*;

/**
 * 
 * @author Adrian Cole
 * 
 */
public class CaptureVAppOptions {

   private String description;

   public CaptureVAppOptions withDescription(String description) {
      checkNotNull(description, "description");
      this.description = description;
      return this;
   }

   public String getDescription() {
      return description;
   }

   public static class Builder {

      /**
       * @see CaptureVAppOptions#withDescription(String)
       */
      public static CaptureVAppOptions withDescription(String description) {
         CaptureVAppOptions options = new CaptureVAppOptions();
         return options.withDescription(description);
      }
   }

}

==> vcloud-1.7.2-sources.jar: org/jclouds/vcloud/options/CaptureVAppOptions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.vcloud.options;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * 
 * @author Adrian Cole
 * 
 */
public class CaptureVAppOptions {

   private String description;

   public CaptureVAppOptions withDescription(String description) {
      checkNotNull(description, "description");
      this.description = description;
      return this;
   }

   public String getDescription() {
      return description;
   }

   public static class Builder {

      /**
       * @see CaptureVAppOptions#withDescription(String)
       */
      public static CaptureVAppOptions withDescription(String description) {
         CaptureVAppOptions options = new CaptureVAppOptions();
         return options.withDescription(description);
      }
   }

}
